#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FAST_LDEXP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_FAST_LDEXP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/fast_ldexp.hpp>

#endif
